;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "project-tasks" "20241220.1028"
  "Efficient task management for your project."
  '((emacs   "26.1")
    (project "0.6.0"))
  :url "https://github.com/TxGVNN/project-tasks"
  :commit "1faaa975c99e358165cfc3df160c21c2c611e1c3"
  :revdesc "1faaa975c99e"
  :keywords '("project" "workflow" "tools")
  :authors '(("Giap Tran" . "txgvnn@gmail.com"))
  :maintainers '(("Giap Tran" . "txgvnn@gmail.com")))
